@@ -12,11 +12,11 @@ import (
 	"strings"
 	"unicode"
 
-	"github.com/twpayne/go-vfs/v4"
+	"github.com/twpayne/go-vfs/v5"
 )
 
 // Kernel returns the kernel information parsed from /proc/sys/kernel.
-func Kernel(fileSystem vfs.FS) (map[string]interface{}, error) {
+func Kernel(fileSystem vfs.FS) (map[string]any, error) {
 	const procSysKernel = "/proc/sys/kernel"
 
 	switch fileInfo, err := fileSystem.Stat(procSysKernel); {
@@ -30,7 +30,7 @@ func Kernel(fileSystem vfs.FS) (map[string]interface{}, error) {
 		return nil, nil
 	}
 
-	kernel := make(map[string]interface{})
+	kernel := make(map[string]any)
 	for _, filename := range []string{
 		"osrelease",
 		"ostype",
@@ -52,12 +52,12 @@ func Kernel(fileSystem vfs.FS) (map[string]interface{}, error) {
 
 // OSRelease returns the operating system identification data as defined by the
 // os-release specification.
-func OSRelease(system System) (map[string]interface{}, error) {
-	for _, filename := range []AbsPath{
-		NewAbsPath("/etc/os-release"),
-		NewAbsPath("/usr/lib/os-release"),
+func OSRelease(fileSystem vfs.FS) (map[string]any, error) {
+	for _, filename := range []string{
+		"/etc/os-release",
+		"/usr/lib/os-release",
 	} {
-		data, err := system.ReadFile(filename)
+		data, err := fileSystem.ReadFile(filename)
 		if errors.Is(err, fs.ErrNotExist) {
 			continue
 		} else if err != nil {
@@ -84,8 +84,8 @@ func maybeUnquote(s string) string {
 
 // parseOSRelease parses operating system identification data from r as defined
 // by the os-release specification.
-func parseOSRelease(r io.Reader) (map[string]interface{}, error) {
-	result := make(map[string]interface{})
+func parseOSRelease(r io.Reader) (map[string]any, error) {
+	result := make(map[string]any)
 	s := bufio.NewScanner(r)
 	for s.Scan() {
 		// Trim all leading whitespace, but not necessarily trailing whitespace.
@@ -94,13 +94,11 @@ func parseOSRelease(r io.Reader) (map[string]interface{}, error) {
 		if len(token) == 0 || token[0] == '#' {
 			continue
 		}
-		fields := strings.SplitN(token, "=", 2)
-		if len(fields) != 2 {
+		key, value, ok := strings.Cut(token, "=")
+		if !ok {
 			return nil, fmt.Errorf("%s: parse error", token)
 		}
-		key := fields[0]
-		value := maybeUnquote(fields[1])
-		result[key] = value
+		result[key] = maybeUnquote(value)
 	}
 	return result, s.Err()
 }
