@@ -5,20 +5,22 @@ import (
 
 	"github.com/alecthomas/assert/v2"
 	tea "github.com/charmbracelet/bubbletea"
+
+	"github.com/twpayne/chezmoi/v2/internal/chezmoiset"
 )
 
-var keyTypes = map[tea.KeyType]struct{}{
-	tea.KeyCtrlC: {},
-	tea.KeyEnter: {},
-	tea.KeyEsc:   {},
-}
+var keyTypes = chezmoiset.New(
+	tea.KeyCtrlC,
+	tea.KeyEnter,
+	tea.KeyEsc,
+)
 
 func makeKeyMsg(r rune) tea.Msg { //nolint:ireturn,nolintlint
 	key := tea.Key{
 		Type:  tea.KeyRunes,
 		Runes: []rune{r},
 	}
-	if _, ok := keyTypes[tea.KeyType(r)]; ok {
+	if keyTypes.Contains(tea.KeyType(r)) {
 		key = tea.Key{
 			Type: tea.KeyType(r),
 		}
@@ -49,6 +51,6 @@ func testRunModelWithInput[M tea.Model]( //nolint:ireturn,nolintlint
 	return model
 }
 
-func newBool(b bool) *bool       { return &b }
-func newInt64(i int64) *int64    { return &i }
-func newString(s string) *string { return &s }
+func newValue[T any](value T) *T {
+	return &value
+}
