@@ -194,6 +194,7 @@ type Config struct {
 	chattr          chattrCmdConfig
 	dump            dumpCmdConfig
 	executeTemplate executeTemplateCmdConfig
+	ignored         ignoredCmdConfig
 	_import         importCmdConfig
 	init            initCmdConfig
 	managed         managedCmdConfig
@@ -652,11 +653,14 @@ func (c *Config) applyArgs(
 		switch err := sourceState.Apply(targetSystem, c.destSystem, c.persistentState, targetDirAbsPath, targetRelPath, applyOptions); {
 		case errors.Is(err, fs.SkipDir):
 			continue
-		case err != nil && c.keepGoing:
-			c.errorf("%v\n", err)
-			keptGoingAfterErr = true
 		case err != nil:
-			return err
+			err = fmt.Errorf("%s: %w", targetRelPath, err)
+			if c.keepGoing {
+				c.errorf("%v\n", err)
+				keptGoingAfterErr = true
+			} else {
+				return err
+			}
 		}
 	}
 
@@ -2219,23 +2223,28 @@ func (c *Config) progressAutoFunc() bool {
 func (c *Config) newTemplateData(cmd *cobra.Command) *templateData {
 	// Determine the user's username and group, if possible.
 	//
-	// user.Current and user.LookupGroupId in Go's standard library are
+	// os/user.Current and os/user.LookupGroupId in Go's standard library are
 	// generally unreliable, so work around errors if possible, or ignore them.
 	//
+	// On Android, user.Current always fails. Instead, use $LOGNAME (as this is
+	// set by Termux), or $USER if $LOGNAME is not set.
+	//
 	// If CGO is disabled, then the Go standard library falls back to parsing
 	// /etc/passwd and /etc/group, which will return incorrect results without
 	// error if the system uses an alternative password database such as NIS or
 	// LDAP.
 	//
-	// If CGO is enabled then user.Current and user.LookupGroupId will use the
-	// underlying libc functions, namely getpwuid_r and getgrnam_r. If linked
-	// with glibc this will return the correct result. If linked with musl then
-	// they will use musl's implementation which, like Go's non-CGO
+	// If CGO is enabled then os/user.Current and os/user.LookupGroupId will use
+	// the underlying libc functions, namely getpwuid_r and getgrnam_r. If
+	// linked with glibc this will return the correct result. If linked with
+	// musl then they will use musl's implementation which, like Go's non-CGO
 	// implementation, also only parses /etc/passwd and /etc/group and so also
 	// returns incorrect results without error if NIS or LDAP are being used.
 	//
-	// On Windows, the user's group ID returned by user.Current() is an SID and
-	// no further useful lookup is possible with Go's standard library.
+	// On Windows, the user's group ID returned by os/user.Current() is an SID
+	// and no further useful lookup is possible with Go's standard library.
+	//
+	// If os/user.Current fails, then fallback to $USER.
 	//
 	// Since neither the username nor the group are likely widely used in
 	// templates, leave these variables unset if their values cannot be
@@ -2243,7 +2252,9 @@ func (c *Config) newTemplateData(cmd *cobra.Command) *templateData {
 	// alerting the user to the problem and allowing them to find alternative
 	// solutions.
 	var gid, group, uid, username string
-	if currentUser, err := user.Current(); err == nil {
+	if runtime.GOOS == "android" {
+		username = firstNonEmptyString(os.Getenv("LOGNAME"), os.Getenv("USER"))
+	} else if currentUser, err := user.Current(); err == nil {
 		gid = currentUser.Gid
 		uid = currentUser.Uid
 		username = currentUser.Username
@@ -2657,6 +2668,23 @@ func (c *Config) writeOutput(data []byte) error {
 	return os.WriteFile(c.outputAbsPath.String(), data, 0o666) //nolint:gosec
 }
 
+type writePathsOptions struct {
+	tree bool
+}
+
+func (c *Config) writePaths(paths []string, options writePathsOptions) error {
+	builder := strings.Builder{}
+	if options.tree {
+		newPathListTreeFromPathsSlice(paths).writeChildren(&builder, "", "  ")
+	} else {
+		sort.Strings(paths)
+		for _, path := range paths {
+			fmt.Fprintln(&builder, path)
+		}
+	}
+	return c.writeOutputString(builder.String())
+}
+
 // writeOutputString writes data to the configured output.
 func (c *Config) writeOutputString(data string) error {
 	return c.writeOutput([]byte(data))
