@@ -3,8 +3,7 @@ package cmd
 func (c *Config) decryptTemplateFunc(ciphertext string) string {
 	plaintextBytes, err := c.encryption.Decrypt([]byte(ciphertext))
 	if err != nil {
-		returnTemplateError(err)
-		return ""
+		panic(err)
 	}
 	return string(plaintextBytes)
 }
@@ -12,8 +11,7 @@ func (c *Config) decryptTemplateFunc(ciphertext string) string {
 func (c *Config) encryptTemplateFunc(plaintext string) string {
 	ciphertextBytes, err := c.encryption.Encrypt([]byte(plaintext))
 	if err != nil {
-		returnTemplateError(err)
-		return ""
+		panic(err)
 	}
 	return string(ciphertextBytes)
 }
