@@ -11,13 +11,15 @@ import (
 
 func (c *Config) newLicenseCmd() *cobra.Command {
 	licenseCmd := &cobra.Command{
-		Use:         "license",
-		Short:       "Print license",
-		Long:        mustLongHelp("license"),
-		Example:     example("license"),
-		Args:        cobra.NoArgs,
-		RunE:        c.runLicenseCmd,
-		Annotations: newAnnotations(),
+		Use:     "license",
+		Short:   "Print license",
+		Long:    mustLongHelp("license"),
+		Example: example("license"),
+		Args:    cobra.NoArgs,
+		RunE:    c.runLicenseCmd,
+		Annotations: newAnnotations(
+			doesNotRequireValidConfig,
+		),
 	}
 
 	return licenseCmd
