@@ -4,7 +4,6 @@ import (
 	"fmt"
 	"io/fs"
 	"sort"
-	"strings"
 
 	"github.com/spf13/cobra"
 
@@ -14,6 +13,7 @@ import (
 
 type unmanagedCmdConfig struct {
 	pathStyle chezmoi.PathStyle
+	tree      bool
 }
 
 func (c *Config) newUnmanagedCmd() *cobra.Command {
@@ -28,6 +28,7 @@ func (c *Config) newUnmanagedCmd() *cobra.Command {
 	}
 
 	unmanagedCmd.Flags().VarP(&c.unmanaged.pathStyle, "path-style", "p", "Path style")
+	unmanagedCmd.Flags().BoolVarP(&c.unmanaged.tree, "tree", "t", c.unmanaged.tree, "Print paths as a tree")
 
 	return unmanagedCmd
 }
@@ -93,16 +94,18 @@ func (c *Config) runUnmanagedCmd(cmd *cobra.Command, args []string, sourceState
 		}
 	}
 
-	builder := strings.Builder{}
-	sortedRelPaths := chezmoi.RelPaths(unmanagedRelPaths.Elements())
-	sort.Sort(sortedRelPaths)
-	for _, relPath := range sortedRelPaths {
-		switch c.unmanaged.pathStyle {
-		case chezmoi.PathStyleAbsolute:
-			fmt.Fprintln(&builder, c.DestDirAbsPath.Join(relPath))
-		case chezmoi.PathStyleRelative:
-			fmt.Fprintln(&builder, relPath)
+	paths := make([]fmt.Stringer, 0, len(unmanagedRelPaths.Elements()))
+	for relPath := range unmanagedRelPaths {
+		var path fmt.Stringer
+		if c.unmanaged.pathStyle == chezmoi.PathStyleAbsolute {
+			path = c.DestDirAbsPath.Join(relPath)
+		} else {
+			path = relPath
 		}
+		paths = append(paths, path)
 	}
-	return c.writeOutputString(builder.String())
+
+	return c.writePaths(stringersToStrings(paths), writePathsOptions{
+		tree: c.unmanaged.tree,
+	})
 }
